if exists ( Select * from sysobjects where id = object_id ( 'dbo.A_Stat_Conference' ) )
 	Drop Table dbo.A_Stat_Conference
GO

Create table dbo.A_Stat_Conference
(
	Id uniqueidentifier Primary key,
	Room int,
	Name nvarchar ( 500 ),
	Description ntext, 
	TimeStart DateTime,
	TimeStop DateTime,
	Director uniqueidentifier,
	IsRecorded bit,
	IdRecDir int,
	Type int
)
GO

CREATE  INDEX [idx_StatConf_TStart_TStop] ON [dbo].[A_Stat_Conference]([TimeStart], [TimeStop]) WITH  FILLFACTOR = 80 ON [PRIMARY]
GO


if exists ( Select * from sysobjects where id = object_id ( 'dbo.A_Stat_Conference_Competitors' ) )
 	Drop Table dbo.A_Stat_Conference_Competitors
GO

Create table dbo.A_Stat_Conference_Competitors
(
	IdConn uniqueidentifier primary key,
	IdConf uniqueidentifier,	
	IdChain uniqueidentifier,
	IdLine uniqueidentifier,
	IdUser uniqueidentifier,
	LineNum nvarchar ( 8 ),
	TimeStart DateTime,	
	TimeStop DateTime,
	ReasonStart int,
	ReasonStop int,	
	OutNumber nvarchar ( 50 ),
	StrName nvarchar ( 50 ),	
)
GO


if exists ( Select * from sysobjects where id = object_id ( 'dbo.A_Stat_Conference_Start' ) )
 	Drop Procedure dbo.A_Stat_Conference_Start
GO

Create Procedure dbo.A_Stat_Conference_Start
	@id uniqueidentifier,
	@room int,
	@name nvarchar ( 500 ) = '',
	@descr ntext = '',
	@timestart datetime,
	@director uniqueidentifier,
	@isrecorded int,
	@recorddir nvarchar ( 1000 ),
	@type int
As
Begin

	--   
	Declare @idrecdir int
	set @idrecdir = 0

	if (( @isrecorded > 0 ) and ( @recorddir != '' ))
	begin
		Select @idrecdir = Max ( id ) 
		From A_Stat_RecordDirectories

		Declare @nowrecdir nvarchar ( 1000 )
		Select @nowrecdir = path 
		From A_Stat_RecordDirectories
		Where Id = @idrecdir

		if (( @nowrecdir != @recorddir ) or ( @nowrecdir is null ))
		begin
			Insert into A_Stat_RecordDirectories
			Values ( @recorddir, @timestart )
			
			set @idrecdir = @@identity
		end
	end

	--   
	Insert into A_Stat_Conference 
	( Id, Room, Name, Description, TimeStart, Director, IsRecorded, IdRecDir, Type )
	Values
	( @id, @room, @name, @descr, @timestart, @director, @isrecorded, @idrecdir, @type )
End
GO


if exists ( Select * from sysobjects where id = object_id ( 'dbo.A_Stat_Conference_Stop' ) )
 	Drop Procedure dbo.A_Stat_Conference_Stop
GO

Create Procedure dbo.A_Stat_Conference_Stop
	@id uniqueidentifier,
	@timestop datetime,
	@name nvarchar ( 500 ) = NULL,
	@descr ntext = NULL,
	@type int = NULL	
As
Begin
     
      --   
      Update A_Stat_Conference 
      Set TimeStop = @timestop,
	Name = case when ( @name is null ) then Name else @name end,
	Description = case when ( @descr is null ) then Description else @descr end,
	Type = case when ( @type is null ) then Type else @type end
      Where Id = @id

	--    
	Update A_Stat_Conference_Competitors
	Set TimeStop = @timestop
	Where IdConf = @id 
		And TimeStop is NULL
End
GO


if exists ( Select * from sysobjects where id = object_id ( 'dbo.A_Stat_Conference_CompetitorAdd' ) )
 	Drop Procedure dbo.A_Stat_Conference_CompetitorAdd
GO

Create Procedure dbo.A_Stat_Conference_CompetitorAdd
	@idconn uniqueidentifier,
	@idconf uniqueidentifier,	
	@idchain uniqueidentifier,
	@idline uniqueidentifier,
	@iduser uniqueidentifier,
	@linenum nvarchar ( 8 ),
	@timestart DateTime,
	@reasonstart int,
	@outnumber nvarchar ( 50 ),
	@strname nvarchar ( 50 )	
As
Begin
	Insert into A_Stat_Conference_Competitors 
		( IdConn, IdConf, IdChain, IdLine, IdUser, LineNum, TimeStart, ReasonStart, OutNumber, StrName )
	Values
		( @idconn, @idconf, @idchain, @idline, @iduser, @linenum, @timestart, @reasonstart, @outnumber, @strname )

End
GO


if exists ( Select * from sysobjects where id = object_id ( 'dbo.A_Stat_Conference_CompetitorRemove' ) )
 	Drop Procedure dbo.A_Stat_Conference_CompetitorRemove
GO

Create Procedure dbo.A_Stat_Conference_CompetitorRemove
	@idconf uniqueidentifier,
	@idconn uniqueidentifier,
	@idchain uniqueidentifier,
	@timestop datetime,
	@reasonstop int
As
Begin
	Update A_Stat_Conference_Competitors 
	Set TimeStop = @timestop,
		ReasonStop = @reasonstop
	Where IdConn = @idconn
		And IdConf = @idconf
		And IdChain = @idchain
End
GO



if exists ( Select * from sysobjects where id = object_id ( 'dbo.A_Stat_Connection_CloseAll' ) )
 	Drop Procedure dbo.A_Stat_Connection_CloseAll
GO

Create Procedure dbo.A_Stat_Connection_CloseAll	
	@timeoff	datetime,
	@reasonstop	int
as
begin	

	declare @lastpingtime datetime
	select @lastpingtime = valueDateTime From A_Settings where [name] like 'PBXStatusServerPingTime'
	if ( @@rowcount = 0 )
		set @lastpingtime = @timeoff
		
	-- 
	Update A_Stat_Connections_1x1 --With ( TabLock )
		Set 
			ReasonStop = @reasonstop,			
			TimeStop = @lastpingtime,
			StopSide = -1
		Where
			TimeStop is null


	-- 
	Update A_Stat_Conference --With ( TabLock )
		Set
			TimeStop = @lastpingtime
		Where
			TimeStop is null

	Update A_Stat_Conference_Competitors --With ( TabLock )
		Set
			ReasonStop = @reasonstop,
			TimeStop = @lastpingtime
		Where
			TimeStop is null		
end
GO