
if exists ( Select * from sysobjects where id=object_id ( 'dbo.A_Stat_Comments' ) )
	Drop table dbo.A_Stat_Comments
GO

Create table dbo.A_Stat_Comments
(
	Id uniqueidentifier Primary Key,
	Comment ntext
)
GO


if exists ( Select * from sysobjects where id=object_id ( 'dbo.A_Stat_Comments_GetCommentById' ) )
	Drop procedure dbo.A_Stat_Comments_GetCommentById
GO

Create procedure dbo.A_Stat_Comments_GetCommentById
	@id uniqueidentifier
as
begin
	Select Comment
	From A_Stat_Comments
	Where Id = @id	
end
GO

if exists ( Select * from sysobjects where id=object_id ( 'dbo.A_Stat_Comments_SetCommentById' ) )
	Drop procedure dbo.A_Stat_Comments_SetCommentById
GO

Create procedure dbo.A_Stat_Comments_SetCommentById
	@id uniqueidentifier,
	@comment ntext
as
begin
	declare @filled bit
	set @filled = case when ( @comment IS NULL or @comment like '' ) then 0 else 1 end

	if ( @filled > 0 ) begin

		begin tran statcomments

		Update A_Stat_Comments
		Set Comment = @comment
		Where Id = @id	

		if ( @@rowcount = 0 )
			Insert into A_Stat_Comments ( id, comment )
			Values ( @id, @comment )

		commit tran statcomments
	end

	else begin

		Delete 
		From A_Stat_Comments
		Where Id = @id
	end	
end
GO




if exists ( Select * from sysobjects where id=object_id ( 'dbo.A_Stat_Service_FillTempByFilter' ) )
	Drop procedure dbo.A_Stat_Service_FillTempByFilter
GO

Create PROCEDURE [dbo].[A_Stat_Service_FillTempByFilter]
	@iduser uniqueidentifier,
	@dstart datetime,
	@dstop datetime,
	@tstart datetime,
	@tstop datetime,
	@lentime datetime,
	@taskid uniqueidentifier = NULL, --Task defined
	@fromcc bit = NULL,
	@operatorid uniqueidentifier = NULL, --Operator defined
	@innerprefix nvarchar(100) = NULL, --Internal Number defined
	@outnumber nvarchar(100) = NULL,  --Out Number defined
	@conntype int = -1,
	@showconf bit = 0,
	@comment nvarchar ( 4000 ) = NULL
AS
begin
	--  
	declare @filtercomment bit
	set @filtercomment = case when ( @comment IS NULL or @comment like '' ) then 0 else 1 end


	--Prepare @A_Stat_Connections_1x1_tmp
	Declare @A_Stat_Connections_1x1_tmp1 table( Id uniqueidentifier PRIMARY KEY) 
	Declare @A_Stat_Connections_1x1_tmp table( Id uniqueidentifier PRIMARY KEY, AUSerId uniqueidentifier, BUSerId uniqueidentifier, ALineId uniqueidentifier, BLineId uniqueidentifier) 
	declare @tstartfloat float  declare @tstopfloat float 
	set @tstartfloat = Convert ( float, @tstart )  
	set @tstopfloat  = Convert ( float, @tstop )  
	set @tstartfloat = @tstartfloat - FLOOR ( @tstartfloat )  
	set @tstopfloat = @tstopfloat - FLOOR ( @tstopfloat )  

	declare @lt float
	set @lt = Convert ( float, @lentime ) - Floor ( Convert ( float, @lentime ) )


	--Date & Time Intervals
	Insert into @A_Stat_Connections_1x1_tmp 
	select Id, AUSerId , BUSerId , ALineId , BLineId 
	from A_Stat_Connections_1x1 sc --With ( TabLock )
	where 
		 ( TimeStart >= @dstart ) and ( TimeStart < @dstop ) 
		and ( Convert ( float, TimeStart ) - FLOOR ( Convert ( float, TimeStart ) ) >= @tstartfloat )  
		and ( Convert ( float, TimeStart ) - FLOOR ( Convert ( float, TimeStart ) ) <= @tstopfloat ) 
		and ( CONVERT ( float, TimeStop ) - Convert ( float, TimeAnswer ) >= @lt )
		and (( FromCC is null ) or ( FromCC <= @fromcc ))
		and (@conntype = -1 or (@conntype = 1 and ConnectionType in (4,5)) or (@conntype = 2 and ConnectionType in (1,6,7)) or (@conntype = 3 and ConnectionType in (2,3,8)))
	
		--and not exists(select id from  @A_Stat_Connections_1x1_tmp where id=sc.ID)


	--Permissions
	--Users
	declare @upermitted table ( Id uniqueidentifier Primary Key )
	Insert into @upermitted
		Select UserB
		From A_UserControls auc
		Where UserA = @iduser

	if not exists (select UserB from  A_UserControls where UserA = @iduser and UserB = @iduser)
		Insert into @upermitted (Id) Values (@iduser)

	Declare @commpermitted table ( Id uniqueidentifier PRIMARY KEY)  	 -- Id Connection
	Insert into @commpermitted
		Select  sc.ID --auc.UserB   	
		From @upermitted up
			inner join @A_Stat_Connections_1x1_tmp sc on up.Id = sc.AUserId
	
	Insert into @commpermitted
		Select  sc.ID --auc.UserB   	
		From @upermitted up
			inner join @A_Stat_Connections_1x1_tmp sc on up.Id=sc.BUserId
		Where not exists(select id from @commpermitted where Id=sc.ID)


	--Lines
	print '------Lines'
	declare @lpermitted table ( Id uniqueidentifier Primary Key )
	Insert into @lpermitted
    	 Select IdLine
    	 From A_UserControlLines
    	 Where UserA = @iduser
          and IdLine != '11111111-1111-1111-1111-111111111111'       

	declare @canlistenext int       
	Select @canlistenext = Count ( * ) 
	From A_UserControlLines 
	Where UserA = @iduser and IdLine = '11111111-1111-1111-1111-111111111111'

	if ( @canlistenext > 0 )
    		Insert into @lpermitted
	          Select Id 
        	  From A_ServerExtLines sel
	          Where not exists(select id from @lpermitted where Id = sel.ID)
     
	Insert into @commpermitted
    	 Select sc.ID            
    	 From @lpermitted l
          inner join @A_Stat_Connections_1x1_tmp sc on sc.ALineId=l.Id
    	 Where not exists(select id from @commpermitted where Id = sc.ID)

	Insert into @commpermitted            
    	 Select sc.ID            
    	 From @lpermitted l
          inner join @A_Stat_Connections_1x1_tmp sc on  sc.BLineId=l.Id
    	 Where not exists(select id from @commpermitted where Id = sc.ID)

	print '------Lines'

	delete @A_Stat_Connections_1x1_tmp 
	where id not in (select Id from @commpermitted )

--Numbers 
	--Inner
	if @innerprefix is not null 
	begin
		declare @t table ( nid uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, reactid uniqueidentifier )
		declare @temp table ( id uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, oldrid uniqueidentifier, newrid uniqueidentifier )

		Insert Into @t
			Select np.Id, np.Prefix, rr.InnerAddressType, rr.ReactId
			From A_NumberPlan np
				Inner join A_NumberPlanAction na on na.NumId = np.Id
				Inner join A_Rules r on na.ExtraId = r.Id
				Inner join A_RuleRecords rr on rr.RuleId = r.Id

		declare @cnt int
		set @cnt = 0

		while ( @@rowcount > 0 ) and ( @cnt < 10 )
		begin
			Set @cnt = @cnt + 1

			/*    @cnt - */
			Insert Into @temp
				Select t.nid, t.prefix, t.addrtype, t.reactid, t1.reactid
				From @t t
					Inner join @t t1 on t.Reactid = t1.nId
				Where t.ReactId != t.Nid

			/*    */
			Delete From @t
				From @temp
			Where nid = id and reactid = oldrid

			/* */
			Insert Into @t ( nid, prefix, addrtype, reactid )
				Select id, prefix, addrtype, newrid 
				From @temp

			/* */
			Delete From @temp	
		end --\MakePrefixTableAnyWay condition

		

		--Users
		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from @A_Stat_Connections_1x1_tmp sc
			inner join @t t on sc.AUserID=t.reactid
		where addrtype = 0 and prefix like @innerprefix

		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from @A_Stat_Connections_1x1_tmp sc
			inner join @t t on sc.BUserID=t.reactid
		where addrtype = 0 and prefix like @innerprefix
			and not exists(select id from  @A_Stat_Connections_1x1_tmp1 where id=sc.ID)

		--Lines
		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from @A_Stat_Connections_1x1_tmp sc
			inner join @t t on sc.AUserID=t.reactid
		where addrtype = 1 and prefix like @innerprefix
			and not exists(select id from  @A_Stat_Connections_1x1_tmp1 where id=sc.ID)

		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from @A_Stat_Connections_1x1_tmp sc
			inner join @t t on sc.BUserID=t.reactid
		where addrtype = 1 and prefix like @innerprefix
			and not exists(select id from  @A_Stat_Connections_1x1_tmp1 where id=sc.ID)
		
		delete @A_Stat_Connections_1x1_tmp 
			where id not in (select Id from @A_Stat_Connections_1x1_tmp1 )
		delete @A_Stat_Connections_1x1_tmp1
		
	end --\NUmbers

	--Outer NUMBVERS
	if @OutNumber is not null begin

		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from A_Stat_Connections_1x1 sc --With ( TabLock )
		where  AOutNumber like '%'+@OutNumber+'%'

		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from A_Stat_Connections_1x1 sc --With ( TabLock )
		where  BOutNumber like '%'+@OutNumber+'%'
			and not exists(select id from  @A_Stat_Connections_1x1_tmp1 where id=sc.ID)

		delete @A_Stat_Connections_1x1_tmp 
			where id not in (select Id from @A_Stat_Connections_1x1_tmp1 )
		delete @A_Stat_Connections_1x1_tmp1

	end
	--\Outer NUMBVERS

	--operatorid
	if @operatorid is not null begin

		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from @A_Stat_Connections_1x1_tmp sc
		where  AUserId=@operatorid

		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id 
		from @A_Stat_Connections_1x1_tmp sc
		where  BUserId=@operatorid
			and not exists(select id from  @A_Stat_Connections_1x1_tmp1 where id=sc.ID)

		delete @A_Stat_Connections_1x1_tmp 
			where id not in (select Id from @A_Stat_Connections_1x1_tmp1 )
		delete @A_Stat_Connections_1x1_tmp1
	end

	if ( @filtercomment > 0 ) begin

		Delete 
		From @A_Stat_Connections_1x1_tmp
		Where id not in ( Select Id From A_Stat_Comments Where Comment like '%' + @comment + '%' )
	end

	


	-- 

	/*Declare @upermitted table ( Id uniqueidentifier )
	Insert into @upermitted 
		Select Id From A_USers
	
	Declare @dstart datetime
	Declare @dstop datetime
	Set @dstart = DateAdd ( d, -5, GetDate() )
	Set @dstop = GetDate()
*/
    if ( @showconf = 0 )
    begin

	Select sc.*
	FROM A_Stat_Connections_1x1 sc --With ( TabLock )--,@ulpermitted ul,@tasks t
		Inner join @A_Stat_Connections_1x1_tmp sct on sc.Id=sct.Id
		--Inner Join @commpermitted cp on sc.ID=cp.ID
    end

    else

    begin

	--   	
	Declare @A_Stat_Conference_tmp1 table ( Id uniqueidentifier PRIMARY KEY, RecordAccess int, Director uniqueidentifier )

	Insert into @A_Stat_Conference_tmp1
		Select Id, RecordAccess, Director 
		FROM A_Stat_Conference sc
		Where (( TimeStart <= @dstart ) and ( TimeStop > @dstart ))
			or (( TimeStart < @dstop ) and ( TimeStop >= @dstop ))
			or (( TimeStart <= @dstart ) and ( TimeStop > @dstart ))
			or (( TimeStart >= @dstart ) and ( TimeStop <= @dstop ))

	--    ( )
	if ( @filtercomment > 0 )
	  begin
		Delete 
		From @A_Stat_Conference_tmp1
		Where id not in ( Select Id From A_Stat_Comments Where Comment like '%' + @comment + '%' )
	  end


	--   
	Declare @A_Stat_Conference_tmp2 table ( Id uniqueidentifier PRIMARY KEY )

	Insert into @A_Stat_Conference_tmp2
		Select sc.Id From @A_Stat_Conference_tmp1 sc
			Inner join @upermitted up on sc.Director = up.Id
		Where sc.RecordAccess = 1 --  

	Insert into @A_Stat_Conference_tmp2
		Select sc.Id From @A_Stat_Conference_tmp1 sc			
			Inner join A_Stat_Conference_Competitors scc on sc.Id = scc.IdConf
			Inner join @upermitted up on scc.IdUser = up.Id
		Where sc.RecordAccess = 2 -- 
		Group By sc.Id

	Insert into @A_Stat_Conference_tmp2
		Select sc.Id From @A_Stat_Conference_tmp1 sc
			Inner join A_Stat_Conference_RecordAccessUsers scr on sc.Id = scr.IdConf
			Inner join @upermitted up on scr.IdUser = up.Id
		Where sc.RecordAccess = 3 --  
		Group By sc.Id

		

	Declare @idempty uniqueidentifier
	Set @idempty = '00000000-0000-0000-0000-000000000000'
	
	Declare @idconfuser uniqueidentifier
	Set @idconfuser = 'CF000000-0000-0000-0000-000000000000'


	Select * From
	(
		Select sc.*, 
			0 as IsConf, @idempty as Director, sc.TimeStart as CTS, 
			case When ( c.Id is null ) then 0 else 1 end as HasComment
		FROM A_Stat_Connections_1x1 sc --With ( TabLock )--,@ulpermitted ul,@tasks t
			Inner join @A_Stat_Connections_1x1_tmp sct on sc.Id=sct.Id
			Left join A_Stat_Comments c on sc.Id = c.Id
			--Inner Join @commpermitted cp on sc.ID=cp.ID

		Union All


		Select IdConn, IdChain, @idempty as IdPrev, @idempty as IdNext, 
			scc.TimeStart, scc.TimeStart as TimeAnswer, scc.TimeStop, 
			ReasonStart, ReasonStop, 0 as StopSide, 
			IdLine, IdConf, OutNumber, '', LineNum, cast ( Room as nvarchar ( 10 ) ), 
			IdUser, @idconfuser, '', '', IsRecorded, case when sc.Type = 1 then 11/**/ else 10/**/ end, 
			StrName, case when Name != '' then Name else '#' + cast ( Room as nvarchar ( 10 ) ) end, 
			0, 1, IdRecDir, 
			1 as IsConf, sc.Director, sc.TimeStart as CTS,
			case When ( c.Id is null ) then 0 else 1 end as HasComment
		FROM A_Stat_Conference_Competitors scc
			Inner join A_Stat_Conference sc on sc.Id = scc.IdConf
			Inner join @A_Stat_Conference_tmp2 sct on sc.Id = sct.Id --  
			Left join A_Stat_Comments c on sc.Id = c.Id
			--Inner join @upermitted up on up.Id = scc.IdUser --             
		Where ((( scc.TimeStart <= @dstart ) and ( scc.TimeStop > @dstart ))
			or (( scc.TimeStart < @dstop ) and ( scc.TimeStop >= @dstop ))
			or (( scc.TimeStart <= @dstart ) and ( scc.TimeStop > @dstart ))
			or (( scc.TimeStart >= @dstart ) and ( scc.TimeStop <= @dstop )))
			and (( @operatorid is null ) or ( scc.IdUser = @operatorid ))
	)a
    end

end
GO


if exists ( Select * from sysobjects where id=object_id ( 'dbo.A_Stat_Office_GetJournal' ) )
	Drop procedure dbo.A_Stat_Office_GetJournal
GO

Create procedure [dbo].[A_Stat_Office_GetJournal]
	@iduser uniqueidentifier,
	@dstart datetime,
	@dstop datetime,
	@tstart datetime,
	@tstop datetime,
	@lentime datetime,
	@taskid uniqueidentifier = NULL, --Task defined
	@fromcc bit = NULL,
	@operatorid uniqueidentifier = NULL, --Operator defined
	@innerprefix nvarchar(100) = NULL, --Internal Number defined
	@outnumber nvarchar(100) = NULL,  --Out Number defined
	@conntype int = -1,
	-- @showconference int = 1,
	@comment nvarchar ( 4000 ) = NULL
as
begin	
	Declare @id0 uniqueidentifier
	Set @id0 = '00000000-0000-0000-0000-000000000000'

	Select top 0 *, 
		0 as IsConf, @id0 as Director, GetDate() as CTS, 
		0 as HasComment 
	Into #t 
	From A_Stat_Connections_1x1
	Insert into #t Exec A_Stat_Service_FillTempByFilter
		@iduser,
		@dstart,
		@dstop,
		@tstart,
		@tstop,
		@lentime,
		@taskid,
		@fromcc,
		@operatorid,
		@innerprefix,
		@outnumber,
		@conntype,
		1, -- show conference,
		@comment

	Select top 1000 t.*, TimeStop - TimeAnswer as Length, TimeAnswer - TimeStart as AnswerLength
	From #t t
	Order By TimeStart Desc
end
GO

if exists ( Select * from sysobjects where id=object_id ( 'dbo.A_Stat_MyCalls_Get' ) )
	Drop procedure dbo.A_Stat_MyCalls_Get
GO

Create procedure [dbo].[A_Stat_MyCalls_Get]
	@media 		int, --1 - , 2 - , 3 - , 0 - 
	@type 		int, --1 - , 2 - , 3 - , 0 - , 10 - , 11 - 
	@dstart 	datetime,
	@dstop 		datetime,
	@number 	nvarchar ( 50 ),
	@showivr 	bit,
	@userid 	uniqueidentifier,
	@comment 	nvarchar ( 4000 ) = NULL
as
begin

/*
	declare @media 	int --1 - , 2 - , 3 - , 0 - 
	declare @type 	int --1 - , 2 - , 3 - , 0 - 
	declare @dstart datetime
	declare @dstop 	datetime
	declare @number nvarchar ( 50 )
	declare @userid uniqueidentifier

	set dateformat dmy
	set @media = 0
	set @type = 0
	set @dstart = '16.12.2006'
	set @dstop = '16.12.2006'
	set @number = ''
	select @userid = id from A_users where login like 'Peter'	

*/

	--  
	declare @filtercomment bit
	set @filtercomment = case when ( @comment IS NULL or @comment like '' ) then 0 else 1 end

	Declare @id0 uniqueidentifier
	Set @id0 = '00000000-0000-0000-0000-000000000000'

	Declare @ids table ( id uniqueidentifier )	

	if ( @number = '' )
		Insert into @ids
			Select Id
			From A_Stat_Connections_1x1 sc --with ( TabLock )
			Where TimeStart > @dstart 
				and TimeStart < @dstop
				and (( AUserId = @userid and (@type = 2 or @type = 0) ) or ( BUserId = @userid and ( @type = 1  or @type = 0 ) ))
				and ( @showivr = 1 or (( AUserId != 'AB000000-0000-0000-0000-000000000000' ) and ( BUserId != 'AB000000-0000-0000-0000-000000000000' )))
	else
		Insert into @ids
			Select Id
			From A_Stat_Connections_1x1 sc --with ( TabLock )
			Where TimeStart > @dstart 
				and TimeStart < @dstop
				and (( AUserId = @userid and (@type = 2 or @type = 0) and BOutNumber like @number ) or ( BUserId = @userid and ( @type = 1  or @type = 0 ) and AOutNumber like @number ))	
				and ( @showivr = 1 or (( AUserId != 'AB000000-0000-0000-0000-000000000000' ) and ( BUserId != 'AB000000-0000-0000-0000-000000000000' )))
		
	Declare @output table ( Id uniqueidentifier, IdChain uniqueidentifier, Media int, Type int, TimeStart DateTime, Length DateTime, Number nvarchar ( 50 ) collate database_default, AbonentName nvarchar ( 100 ) collate database_default, 
				IsRecorded int, IdRecDir int, ALineNum nvarchar ( 5 ) collate database_default, BLineNum nvarchar ( 5 )  collate database_default, --ARecFile nvarchar ( 100 ), BRecFile nvarchar ( 100 ), 
				AUserId uniqueidentifier, BUserId uniqueidentifier, 
				ALineId uniqueidentifier, BLineId uniqueidentifier, 
				AOutNumber nvarchar ( 50 ) collate database_default, BOutNumber nvarchar ( 50 ) collate database_default, 
				AStr nvarchar ( 100 ) collate database_default, BStr nvarchar ( 100 ) collate database_default, IsConf int, Director uniqueidentifier, CTS DateTime )
	-------------------------------------
	--  -----------------------
	-------------------------------------

	Insert into @output
		Select sc.Id, sc.IdChain, null, 0, sc.TimeStart, sc.TimeStop - sc.TimeAnswer as Length, '', '',
			IsRecorded, IdRecDir, ALineNum, BLineNum, --ARecFile, BRecFile, 
			AUserId, BUserId, ALineId, BLineId, AOutNumber, BOutNumber, AStr, BStr,
			0 as IsConf, @id0 as Director, sc.TimeStart as CTS
		From A_Stat_Connections_1x1 sc --with ( TabLock )
			inner join @ids ids on sc.Id = ids.id

	--    ( )
	if ( @filtercomment > 0 )
	  begin
		Delete 
		From @output
		Where id not in ( Select Id From A_Stat_Comments Where Comment like '%' + @comment + '%' )
	  end

	-------------------------------------
	--  ----------------------
	-------------------------------------
    if (( @type = 0 ) or ( @type = 10 ) or ( @type = 11 ))
    begin
	

	--   	
	Declare @A_Stat_Conference_Ctmp1 table ( IdConn uniqueidentifier PRIMARY KEY )
	Declare @A_Stat_Conference_tmp1 table ( Id uniqueidentifier PRIMARY KEY, RecordAccess int, Director uniqueidentifier )

	Insert into @A_Stat_Conference_Ctmp1
		Select IdConn
		FROM A_Stat_Conference_Competitors scc
		Where (( TimeStart >= @dstart ) and ( TimeStart < @dstop ))
			And IdUser = @userid

	Insert into @A_Stat_Conference_tmp1
		Select Id, RecordAccess, Director 
		FROM A_Stat_Conference sc
		Where (( TimeStart <= @dstart ) and ( TimeStop > @dstart ))
			or (( TimeStart < @dstop ) and ( TimeStop >= @dstop ))
			or (( TimeStart <= @dstart ) and ( TimeStop > @dstart ))
			or (( TimeStart >= @dstart ) and ( TimeStop <= @dstop ))

	--    ( )
	if ( @filtercomment > 0 )
	  begin
		Delete 
		From @A_Stat_Conference_tmp1
		Where id not in ( Select Id From A_Stat_Comments Where Comment like '%' + @comment + '%' )
	  end

	--   
	Declare @A_Stat_Conference_tmp2 table ( Id uniqueidentifier PRIMARY KEY )

	Insert into @A_Stat_Conference_tmp2
		Select sc.Id From @A_Stat_Conference_tmp1 sc			
		Where sc.RecordAccess = 1 --  
			And sc.Director = @userid

	Insert into @A_Stat_Conference_tmp2
		Select sc.Id From @A_Stat_Conference_tmp1 sc			
			Inner join A_Stat_Conference_Competitors scc on sc.Id = scc.IdConf
		Where sc.RecordAccess = 2 -- 
			And scc.IdUser = @userid
		Group By sc.Id

	Insert into @A_Stat_Conference_tmp2
		Select sc.Id From @A_Stat_Conference_tmp1 sc
			Inner join A_Stat_Conference_RecordAccessUsers scr on sc.Id = scr.IdConf
		Where sc.RecordAccess = 3 --  
			And scr.IdUser = @userid
		Group By sc.Id

		

	Declare @idconfuser uniqueidentifier
	Set @idconfuser = 'CF000000-0000-0000-0000-000000000000'

	Insert into @output
		Select IdConn, IdChain, 
			case when sc.Type = 1 then 11/**/ else 10/**/ end, 
			case when sc.Type = 1 then 11/**/ else 10/**/ end,
			scc.TimeStart, scc.TimeStop - scc.TimeStart as Length, 
			'', case when Name != '' then Name else '#' + cast ( Room as nvarchar ( 10 ) ) end,
			case when ( sct.Id is NULL ) then 0 else sc.IsRecorded end,  
			sc.IdRecDir, LineNum, sc.Room, 
			scc.IdUser, @idconfuser,
			scc.IdLine, IdConf,
			'', '', StrName, case when Name != '' then Name else '#' + cast ( Room as nvarchar ( 10 ) ) end,
			1 as IsConf, Director, sc.TimeStart as CTS
		FROM A_Stat_Conference_Competitors scc
			Inner join A_Stat_Conference sc on sc.Id = scc.IdConf
			Left join @A_Stat_Conference_tmp2 sct on sc.Id = sct.Id --    
		Where ((( scc.TimeStart <= @dstart ) and ( scc.TimeStop > @dstart ))
			or (( scc.TimeStart < @dstop ) and ( scc.TimeStop >= @dstop ))
			or (( scc.TimeStart <= @dstart ) and ( scc.TimeStop > @dstart ))
			or (( scc.TimeStart >= @dstart ) and ( scc.TimeStop <= @dstop )))
			And scc.IdUser = @userid
			And ((( sc.Type = 1 ) and ( @type = 11 )) or (( sc.Type = 0 ) and ( @type = 10 )) or ( @type = 0 ))
    end

	-----------------------------------
  	--  -----------------
	-----------------------------------

	Update o
	Set o.Type =  1,
		o.Number = AOutNumber
	From @output o
	Where o.BUserId = @userid
		And Type = 0

	Update o
	Set o.Type =  2,
		o.Number = BOutNumber
	From @output o
	Where o.AUserId = @userid
		And Type = 0

	Update o
	Set o.Media = 1
	From @output o, A_ServerExtLines el
	Where o.ALineId = el.Id or o.BLineId = el.Id

	Update o
	Set o.Media = 2
	From @output o
	Where o.Media is null
	
	Update o
	Set o.AbonentName = u.Name
	From @output o, A_Users u
	Where ( o.AUserId = @userid and o.BUserId = u.Id ) or ( o.BUserId = @userid and o.AUserId = u.Id )

	Update o
	Set o.AbonentName = c.Name
	From @output o, A_Clients c, A_ClientContacts cc
	Where o.Number = cc.Content and cc.IdClient = c.Id

	if ( @showivr = 1 )
		Update o
		Set o.AbonentName = 'IVR'
		From @output o
		Where o.AUserId = 'AB000000-0000-0000-0000-000000000000' or o.BUserId = 'AB000000-0000-0000-0000-000000000000'

	Update o
	Set o.AbonentName = case When o.Type = 1 Then o.AStr else o.BStr end
	From @output o
	Where o.AbonentName = ''-- and o.Number = ''

	Update o
	Set o.AbonentName = ''
	From @output o
	Where o.AbonentName = o.Number

	
	Select sc.Id, IdChain, Media, Type, TimeStart, Length, ALineNum, BLineNum, Number, AbonentName, IsRecorded, IdRecDir, 
		IsConf, Director, CTS, 
		case When ( c.Id is null ) then 0 else 1 end as HasComment		
	From @output sc
		Left join A_Stat_Comments c on sc.Id = c.Id
	Where ( Media = @media ) or ( @media = 0 ) or ( Type >= 10 )
	Order By TimeStart Desc
end
GO



if exists ( Select * from sysobjects where id=object_id ( 'dbo.A_Stat_Office_Diagramm_AllCalls' ) )
	Drop procedure dbo.A_Stat_Office_Diagramm_AllCalls
GO

Create procedure [dbo].[A_Stat_Office_Diagramm_AllCalls]
	@iduser uniqueidentifier,
	@dstart datetime,
	@dstop datetime,
	@tstart datetime,
	@tstop datetime,
	@lentime datetime,
	@taskid uniqueidentifier = null,
	@fromcc bit = null,
	@operatorid uniqueidentifier = null,
	@innerprefix nvarchar ( 100 ) = null,
	@outnumber nvarchar ( 100 ) = null,
	@conntype int = -1,
	@mode int,
	@comment nvarchar(4000) = null
as

begin
-- .  " "

/*
-- ---------------------------------------------------
	declare @iduser uniqueidentifier
	declare @dstart datetime
	declare @dstop datetime
	declare @tstart datetime
	declare @tstop datetime
	declare @lentime datetime
	declare @taskid uniqueidentifier
	declare @operatorid uniqueidentifier
	declare @innerprefix nvarchar ( 100 )
	declare @outnumber nvarchar ( 100 )
	declare @mode int

	Select @iduser = 'DA803F01-EA77-40FA-BC9D-E2EFB36FD5A8', 
		@dstart = '15.06.2006', 
		@dstop = '20.12.2006', 
		@tstart = '8:00', 
		@tstop = '20:00', 
		@lentime = '0:00:01',
		@mode = 4
--------------------------------------------------------------------
*/
		

	if not exists ( Select * From tempdb..sysobjects where id = object_id('tempdb..#tempstatistics') )
		Select top 0 * into #tempstatistics From A_Stat_Connections_1x1
	else
		delete From #tempstatistics
		
	Insert into #tempstatistics Exec A_Stat_Service_FillTempByFilter
		@iduser,
		@dstart,
		@dstop,
		@tstart,
		@tstop,
		@lentime,
		@taskid,
		@fromcc,
		@operatorid,
		@innerprefix,
		@outnumber,
		@conntype,
		0, -- dont show conf
		@comment
	
	--EStatisticsViewMode.svmByDay:
	if ( @mode = 0 )
 		begin						
			declare @k0 table ( idchain uniqueidentifier, timestop datetime )
			Insert into @k0
				Select IDChain, Max(TimeStop) as TimeStop
				From #tempstatistics							
				Group by IDChain

			Select Year ( timestop ) y, Month ( timestop ) m, Day ( timestop ) d, count ( * ) as Count_
			From @k0
			Group by Year ( timestop ), Month ( timestop ), Day ( timestop )
		end

	--EStatisticsViewMode.svmByHour:
	else if ( @mode = 1 )
		begin
			declare @k1 table ( idchain uniqueidentifier, timestop datetime )
			Insert into @k1
				Select IDChain, Max(TimeStop) as TimeStop
				From #tempstatistics
				Group by IDChain

			Select DatePart ( hour, timestop ) h, count ( * ) as Count_
			From @k1
			Group by DatePart ( hour, timestop )
		end

	--EStatisticsViewMode.svmByOperator:
	else if ( @mode = 2 )
		begin							
			declare @lines2 table ( lineid uniqueidentifier )
			insert into @lines2
				Select Id From A_View_ServerLinesAll
	

			Select uid, sum ( count_ ) count_ from
			(
				Select AUserId as uid, count ( * ) as count_
				From #tempstatistics ts
					Inner Join A_Users u on u.Id = ts.AUserId
				Group by AUserId
			
				Union all
			
				Select BUserId as uid, count ( * ) as count_
				From #tempstatistics ts
					Inner Join A_Users u on u.Id = ts.BUserId
				Group By BUserId

				union

				Select AUserId as uid, count ( * ) as count_
				From #tempstatistics ts
					Inner Join @lines2 l on l.lineid = ts.BLineId
				Where ( ALineNum like 'IVR' )
				Group by AUserId

				Union all
					
				Select BUserId as uid, count ( * ) as count_
				From #tempstatistics ts
					Inner Join @lines2 l on l.lineid = ts.ALineId
				Where ( BLineNum like 'IVR' )
				Group By BUserId
	
			)a
			group by uid
		end

	--EStatisticsViewMode.svmByLine:
	else if ( @mode = 3 )
		begin														
			--declare @lines3 table ( lineid uniqueidentifier )
			--Insert into @lines3
			--	Select Id From A_View_ServerLinesAll

			Declare @lines3 table ( lineid uniqueidentifier, caption nvarchar ( 100 ) )
			Insert into @lines3 (lineid, caption)
				Select id, caption From A_View_ServerLinesAll

			
			Select linenum + case when (( not l.caption is NULL ) and ( l.caption != '' )) then ', ' + l.caption else '' end as linenum, 
				count_
			FROM (
				Select lineid, linenum, sum ( count_ ) count_ from
				(
					Select ALineId as lineid, ALineNum as linenum, count ( * ) as count_
					From #tempstatistics ts
						Inner Join @lines3 l on l.lineid = ts.ALineId	
					Group by ALineId, ALineNum
			
					Union all

					Select BLineId as lineid, BLineNum as linenum, 
						count ( * ) as count_
					From #tempstatistics ts
						Inner Join @lines3 l on l.lineid = ts.BLineId
					Group By BLineId, BLineNum

					Union all
	
					Select ALineId as lineid, ALineNum as linenum, count ( * ) as count_
					From #tempstatistics ts 
						Inner Join @lines3 l on l.lineid = ts.BLineId
					where ALineNum like 'IVR' 
					Group by ALineid, ALineNum

					Union all

					Select BLineId as lineid, BLineNum as linenum, count ( * ) as count_
					From #tempstatistics ts
						Inner Join @lines3 l on l.lineid = ts.ALineId
					where BLineNum like 'IVR'
					Group by BLineId, BLineNum
				)a				
				group by lineid, linenum
			)b
				Left join @lines3 l on b.lineid = l.lineid
		end

	--EStatisticsViewMode.svmByNumber:						
	else if ( @mode = 4 )
	begin
		declare @t table ( nid uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, reactid uniqueidentifier )
		declare @temp table ( id uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, oldrid uniqueidentifier, newrid uniqueidentifier )
				
		Insert Into @t
			Select np.Id, np.Prefix, rr.InnerAddressType, rr.ReactId
			From A_NumberPlan np
				Inner Join A_NumberPlanAction na on na.NumId = np.Id
				Inner Join A_Rules r on na.ExtraId = r.Id
				Inner Join A_RuleRecords rr on rr.RuleId = r.Id


		declare @cnt int
		set @cnt = 0

		while ( @@rowcount > 0 ) and ( @cnt < 10 )
		begin
			Set @cnt = @cnt + 1
	
			/*    @cnt - */
			Insert Into @temp
				Select t.nid, t.prefix, t.addrtype, t.reactid, t1.reactid
				From @t t
					Inner Join @t t1 on t.Reactid = t1.nId
				Where t.ReactId != t.Nid
	
			/*    */
			Delete From @t
				From @temp
			Where nid = id and reactid = oldrid

			/* */
			Insert Into @t ( nid, prefix, addrtype, reactid )
				Select id, prefix, addrtype, newrid From @temp

			/* */
			Delete From @temp	
		end

		declare @lines4 table ( lineid uniqueidentifier )
		insert into @lines4
			Select Id From A_View_ServerIntLinesAll

		Select prefix, sum ( count_ ) count_ from
		(
			Select t1.prefix, 0 as InnerAddrType, count ( * ) as count_
			From #tempstatistics t 
				Inner Join @t t1 on t1.reactid = t.BUserId and t1.addrtype = 0 
				Inner Join A_Users u on u.id = AUserId
			Group by prefix

			Union all

			Select t1.prefix, 0 as InnerAddrType, count ( * ) as count_
			From #tempstatistics t 
				Inner Join @t t1 on t1.reactid = t.BUserId and t1.addrtype = 0 
				Inner Join A_Users u on u.id = BUserId
			Group by prefix

			Union all

			Select t1.prefix, 1 as InnerAddrType, count ( * ) as count_
			From #tempstatistics t 
				Inner Join @t t1 on t1.reactid = t.ALineId and t1.addrtype = 1 
				Inner Join @lines4 l on l.lineid = ALineId
			Group by prefix

			Union all
		
			Select t1.prefix, 1 as InnerAddrType, count ( * ) as count_
			From #tempstatistics t 
				Inner Join @t t1 on t1.reactid = t.BLineId and t1.addrtype = 1 
				Inner Join @lines4 l on l.lineid = BLineId
			Group by prefix
		)a
		Group by prefix
	end
	--EStatisticsViewMode.svmByWeekDay:
	else if ( @mode = 5 )
		begin
			declare @k2 table ( idchain uniqueidentifier, timestop datetime )
			Insert into @k2
				Select IDChain, Max(TimeStop) as TimeStop
				From #tempstatistics
				Group by IDChain

			Select (DatePart(dw, TimeStop)+5)%7 WDay, count ( * ) as Count_
			From @k2
			Group by (DatePart(dw, TimeStop)+5)%7
			Order by WDay
		end

	delete From #tempstatistics

end
GO


if exists ( Select * from sysobjects where id=object_id ( 'dbo.A_Stat_Office_Diagramm_AverageCallTime' ) )
	Drop procedure dbo.A_Stat_Office_Diagramm_AverageCallTime
GO


Create procedure [dbo].[A_Stat_Office_Diagramm_AverageCallTime]
	@iduser uniqueidentifier,
	@dstart datetime,
	@dstop datetime,
	@tstart datetime,
	@tstop datetime,
	@lentime datetime,
	@taskid uniqueidentifier = null,
	@fromcc bit = null,
	@operatorid uniqueidentifier = null,
	@innerprefix nvarchar ( 100 ) = null,
	@outnumber nvarchar ( 100 ) = null,
	@conntype int = -1,
	@mode int,
	@comment nvarchar(4000) = NULL
as

begin
-- .  "  "

/*
-- ---------------------------------------------------
	declare @iduser uniqueidentifier
	declare @dstart datetime
	declare @dstop datetime
	declare @tstart datetime
	declare @tstop datetime
	declare @lentime datetime
	declare @taskid uniqueidentifier
	declare @operatorid uniqueidentifier
	declare @innerprefix nvarchar ( 100 )
	declare @outnumber nvarchar ( 100 )
	declare @mode int

	Select @iduser = 'DA803F01-EA77-40FA-BC9D-E2EFB36FD5A8', 
		@dstart = '15.06.2006', 
		@dstop = '20.12.2006', 
		@tstart = '8:00', 
		@tstop = '20:00', 
		@lentime = '0:00:01',
		@mode = 2
--------------------------------------------------------------------
*/

	if not exists ( Select * From tempdb..sysobjects where id = object_id('tempdb..#tempstatistics') )
		Select top 0 * into #tempstatistics From A_Stat_Connections_1x1
	else
		delete From #tempstatistics
		
	Insert into #tempstatistics 
	Exec A_Stat_Service_FillTempByFilter
		@iduser,
		@dstart,
		@dstop,
		@tstart,
		@tstop,
		@lentime,
		@taskid,
		@fromcc,
		@operatorid,
		@innerprefix,
		@outnumber,
		@conntype,
		0, -- dont show conf
		@comment

	--EStatisticsViewMode.svmByDay:
	if ( @mode = 0 )
 		begin						
			if not exists ( Select * From tempdb..sysobjects where id = object_id('tempdb..#tempstatisticsYMDdateInt') )
				Select top 0 Year( Timestart ) y, Month ( TimeStart ) m, Day ( TimeStart ) D, TimeStop - TimeAnswer length, 1 as count_
				into #tempstatisticsYMDdateInt
				From A_Stat_Connections_1x1
			else
				delete From #tempstatisticsYMDdateInt

			insert into #tempstatisticsYMDdateInt
				Select Year( Timestart ) y, Month ( TimeStart ) m, Day ( TimeStart ) D, Cast ( sum ( CAST ( TimeStop - TimeAnswer as float ) ) as DateTime ) length, Count ( * ) as count_
				From #tempstatistics
				Group By Year( Timestart ), Month ( TimeStart ), Day ( TimeStart )

			Select y, m, d, ( ( ( ( DatePart ( dy, length ) - 1 ) * 24 + DatePart ( hh, length ) ) * 60 + DatePart ( mi, length ) ) * 60 + DatePart ( ss, length ) ) / count_ as AverageSec
			From #tempstatisticsYMDdateInt

			delete From #tempstatisticsYMDdateInt										
		end

	--EStatisticsViewMode.svmByHour:
	else if ( @mode = 1 )
		begin
			if not exists ( Select * From tempdb..sysobjects where id = object_id('tempdb..#tempstatisticsYMDHdateInt') )
				Select top 0 DatePart ( hh, TimeStart ) Hstart, TimeStop - TimeAnswer length, 1 as count_
				into #tempstatisticsYMDHdateInt
				From A_Stat_Connections_1x1
			else
				delete From #tempstatisticsYMDHdateInt

			insert into #tempstatisticsYMDHdateInt
				Select DatePart ( hh, TimeStart ) Hstart, Cast ( sum ( CAST ( TimeStop - TimeAnswer as float ) ) as DateTime ) length, count ( * ) as count_
				From #tempstatistics
				Group By DatePart ( hh, TimeStart )

			Select Hstart, ( ( ( ( DatePart ( dy, length ) - 1 ) * 24 + DatePart ( hh, length ) ) * 60 + DatePart ( mi, length ) ) * 60 + DatePart ( ss, length ) ) / count_ as AverageSec
			From #tempstatisticsYMDHdateInt

			delete From #tempstatisticsYMDHdateInt
		end

	--EStatisticsViewMode.svmByOperator:
	else if ( @mode = 2 )
		begin	
			Select uid, ( ( ( ( DatePart ( dy, length ) - 1 ) * 24 + DatePart ( hh, length ) ) * 60 + DatePart ( mi, length ) ) * 60 + DatePart ( ss, length ) ) / count_ as AverageSec
			From
			(
				Select uid, Cast ( sum ( CAST ( TimeStop - TimeAnswer as float ) ) as DateTime ) length, count ( * ) as count_ From
				(
					Select AUserId as uid, TimeAnswer, TimeStop
					From #tempstatistics
					Where AUserId != 'AB000000-0000-0000-0000-000000000000'
	
					Union all
	
					Select BUserId as uid, TimeAnswer, TimeStop
					From #tempstatistics
					Where BUserId != 'AB000000-0000-0000-0000-000000000000'
				)a
				Group by uid
			)b
		end

	--EStatisticsViewMode.svmByLine:
	else if ( @mode = 3 )
		begin														
			declare @lines3 table ( lineid uniqueidentifier, caption nvarchar ( 100 ) )
			insert into @lines3 (lineid, caption)
				Select id, caption From A_View_ServerLinesAll


			Select linenum + case when (( not l.caption is NULL ) and ( l.caption != '' )) then ', ' + l.caption else '' end as linenum,
				( ( ( ( DatePart ( dy, length ) - 1 ) * 24 + DatePart ( hh, length ) ) * 60 + DatePart ( mi, length ) ) * 60 + DatePart ( ss, length ) ) / count_ as AverageSec
			From
			(
				Select lineid, linenum, Cast ( sum ( CAST ( TimeStop - TimeAnswer as float ) ) as DateTime ) length, count ( * ) as count_ From
				(
					Select ALineId as lineid, ALineNum as linenum, 
						TimeAnswer, TimeStop
					From #tempstatistics ts
					Inner Join @lines3 l on l.lineid = ts.ALineId
	
					Union all
	
					Select BLineId as lineid, BLineNum as linenum, 
						TimeAnswer, TimeStop
					From #tempstatistics ts
					Inner Join @lines3 l on l.lineid = ts.BLineId
				)a
				Group by lineid, linenum
			)b
				Left join @lines3 l on b.lineid = l.lineid
		end

	--EStatisticsViewMode.svmByNumber:						
	else if ( @mode = 4 )
		begin
			declare @t table ( nid uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, reactid uniqueidentifier )
			declare @temp table ( id uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, oldrid uniqueidentifier, newrid uniqueidentifier )
				
			Insert Into @t
				Select np.Id, np.Prefix, rr.InnerAddressType, rr.ReactId
				From A_NumberPlan np
					Inner Join A_NumberPlanAction na on na.NumId = np.Id
					Inner Join A_Rules r on na.ExtraId = r.Id
					Inner Join A_RuleRecords rr on rr.RuleId = r.Id


			declare @cnt int
			set @cnt = 0

			while ( @@rowcount > 0 ) and ( @cnt < 10 )
			begin
				Set @cnt = @cnt + 1
	
				/*    @cnt - */
				Insert Into @temp
					Select t.nid, t.prefix, t.addrtype, t.reactid, t1.reactid
					From @t t
						Inner Join @t t1 on t.Reactid = t1.nId
					Where t.ReactId != t.Nid
	
				/*    */
				Delete From @t
					From @temp
				Where nid = id and reactid = oldrid

				/* */
				Insert Into @t ( nid, prefix, addrtype, reactid )
					Select id, prefix, addrtype, newrid From @temp

				/* */
				Delete From @temp	
			end


			declare @lines4 table ( lineid uniqueidentifier )
			insert into @lines4
				Select Id From A_View_ServerLinesAll


			Select prefix, ( ( ( ( DatePart ( dy, length ) - 1 ) * 24 + DatePart ( hh, length ) ) * 60 + DatePart ( mi, length ) ) * 60 + DatePart ( ss, length ) ) / count_ as AverageSec
			From
			(
				Select prefix, Cast ( sum ( CAST ( TimeStop - TimeAnswer as float ) ) as DateTime ) length, count ( * ) as count_ From
				(
					Select t1.prefix, 0 as InnerAddrType, TimeAnswer, TimeStop
					From #tempstatistics t Inner Join 
						@t t1 on t1.reactid = t.AUserId and t1.addrtype = 0 Inner Join 
						A_Users u on u.id = AUserId

					Union all

					Select t1.prefix, 0 as InnerAddrType, TimeAnswer, TimeStop
					From #tempstatistics t Inner Join 
						@t t1 on t1.reactid = t.BUserId and t1.addrtype = 0 Inner Join 
						A_Users u on u.id = BUserId

					Union all

					Select t1.prefix, 1 as InnerAddrType, TimeAnswer, TimeStop
					From #tempstatistics t Inner Join 
						@t t1 on t1.reactid = t.ALineId and t1.addrtype = 1 inner join
						@lines4 l on l.lineid = ALineId

					Union all

					Select t1.prefix, 1 as InnerAddrType, TimeAnswer, TimeStop
					From #tempstatistics t Inner Join 
						@t t1 on t1.reactid = t.BLineId and t1.addrtype = 1 inner join
						@lines4 l on l.lineid = BLineId
				)a
				Group by prefix
			)b

		end

	--EStatisticsViewMode.svmByWeekDay: // 
	else if ( @mode = 5 )
		begin
			if not exists ( Select * From tempdb..sysobjects where id = object_id('tempdb..#tempstatisticsYMDWDdateInt') )
				Select top 0 1 as WDay, CAST(1 as FLOAT) as Seconds, 1 as count_
				into #tempstatisticsYMDWDdateInt
				From A_Stat_Connections_1x1
			else
				delete From #tempstatisticsYMDWDdateInt


			insert into #tempstatisticsYMDWDdateInt
				select (DatePart(dw, TimeStart)+5)%7 as WDay, ISNULL(SUM(CAST(TimeStop-TimeAnswer as FLOAT))*86400,0) as Seconds, count(*) as count_ From #tempstatistics
				Group by (DatePart(dw, TimeStart)+5)%7
				Order by WDay


			Select WDay, Floor(Seconds/count_) as AverageSec
			From #tempstatisticsYMDWDdateInt


			delete From #tempstatisticsYMDWDdateInt
		end

	delete From #tempstatistics

end
GO


if exists ( Select * from sysobjects where id=object_id ( 'dbo.A_Stat_Office_Diagramm_CallTime' ) )
	Drop procedure dbo.A_Stat_Office_Diagramm_CallTime
GO

Create procedure [dbo].[A_Stat_Office_Diagramm_CallTime]
	@iduser uniqueidentifier,
	@dstart datetime,
	@dstop datetime,
	@tstart datetime,
	@tstop datetime,
	@lentime datetime,
	@taskid uniqueidentifier = null,
	@fromcc bit = null,
	@operatorid uniqueidentifier = null,
	@innerprefix nvarchar ( 100 ) = null,
	@outnumber nvarchar ( 100 ) = null,
	@conntype int = -1,
	@mode int,
	@comment nvarchar (4000) = NULL
as

begin
-- .  " "

/*
-- ---------------------------------------------------
	declare @iduser uniqueidentifier
	declare @dstart datetime
	declare @dstop datetime
	declare @tstart datetime
	declare @tstop datetime
	declare @lentime datetime
	declare @taskid uniqueidentifier
	declare @operatorid uniqueidentifier
	declare @innerprefix nvarchar ( 100 )
	declare @outnumber nvarchar ( 100 )
	declare @mode int

	Select @iduser = 'DA803F01-EA77-40FA-BC9D-E2EFB36FD5A8', 
		@dstart = '15.06.2006', 
		@dstop = '20.12.2006', 
		@tstart = '8:00', 
		@tstop = '20:00', 
		@lentime = '0:00:01',
		@mode = 2
--------------------------------------------------------------------
*/

	if not exists ( Select * From tempdb..sysobjects where id = object_id('tempdb..#tempstatistics') )
		Select top 0 * into #tempstatistics From A_Stat_Connections_1x1
	else
		delete From #tempstatistics
		
	Insert into #tempstatistics 
	Exec A_Stat_Service_FillTempByFilter
		@iduser,
		@dstart,
		@dstop,
		@tstart,
		@tstop,
		@lentime,
		@taskid,
		@fromcc,
		@operatorid,
		@innerprefix,
		@outnumber,
		@conntype,
		0, -- dont show conf
		@comment

	--EStatisticsViewMode.svmByDay:
	if ( @mode = 0 )
 		begin						
			if not exists ( Select * From tempdb..sysobjects where id = object_id('tempdb..#tempstatisticsYMDdate') ) 
				Select top 0 Year( Timestart ) y, Month ( TimeStart ) m, Day ( TimeStart ) D, TimeStop - TimeAnswer length 
				into #tempstatisticsYMDdate 
				From A_Stat_Connections_1x1
			else
				delete From #tempstatisticsYMDdate

			insert into #tempstatisticsYMDdate
				Select Year( Timestart ) y, Month ( TimeStart ) m, Day ( TimeStart ) D, Cast ( sum ( CAST ( TimeStop - TimeAnswer as float ) ) as DateTime ) length
				From #tempstatistics
				Group By Year( Timestart ), Month ( TimeStart ), Day ( TimeStart )


			Select y, m, d, ( DatePart ( dy, length ) - 1 ) * 24 + DatePart ( hh, length ) H, DatePart ( mi, length ) MI, DatePart ( ss, length ) S, DatePart ( ms, length ) MS
			From #tempstatisticsYMDdate

			delete From #tempstatisticsYMDdate										
		end

	--EStatisticsViewMode.svmByHour:
	else if ( @mode = 1 )
		begin
			if not exists ( Select * From tempdb..sysobjects where id = object_id('tempdb..#tempstatisticsYMDHdate') )
				Select top 0 DatePart ( hh, TimeStart ) Hstart, TimeStop - TimeAnswer length 
				into #tempstatisticsYMDHdate 
				From A_Stat_Connections_1x1
			else
				delete From #tempstatisticsYMDHdate

			insert into #tempstatisticsYMDHdate
				Select DatePart ( hh, TimeStart ) Hstart, Cast ( sum ( CAST ( TimeStop - TimeAnswer as float ) ) as DateTime ) length
				From #tempstatistics
				Group By DatePart ( hh, TimeStart )

			Select Hstart, ( DatePart ( dy, length ) - 1 ) * 24 + DatePart ( hh, length ) H, DatePart ( mi, length ) MI, DatePart ( ss, length ) S, DatePart ( ms, length ) MS
			From #tempstatisticsYMDHdate

			delete From #tempstatisticsYMDHdate
		end

	--EStatisticsViewMode.svmByOperator:
	else if ( @mode = 2 )
		begin			
			Select uid, ( DatePart ( dy, length ) - 1 ) * 24 + DatePart ( hh, length ) H, DatePart ( mi, length ) MI, DatePart ( ss, length ) S, DatePart ( ms, length ) MS
			From
			(
				Select uid, Cast ( sum ( CAST ( TimeStop - TimeAnswer as float ) ) as DateTime ) length From
				(
					Select AUserId as uid, TimeAnswer, TimeStop
					From #tempstatistics
					Where AUserId != 'AB000000-0000-0000-0000-000000000000'
	
					Union all
	
					Select BUserId as uid, TimeAnswer, TimeStop
					From #tempstatistics
					Where BUserId != 'AB000000-0000-0000-0000-000000000000'
				)a
				Group by uid
			)b			
		end

	--EStatisticsViewMode.svmByLine:
	else if ( @mode = 3 )
		begin														
			declare @lines table ( lineid uniqueidentifier, caption nvarchar ( 100 ) )
			insert into @lines (lineid, caption)
				Select id, caption From A_View_ServerLinesAll


			Select linenum + case when (( not l.caption is NULL ) and ( l.caption != '' )) then ', ' + l.caption else '' end as linenum,
				( DatePart ( dy, length ) - 1 ) * 24 + DatePart ( hh, length ) H, DatePart ( mi, length ) MI, DatePart ( ss, length ) S, DatePart ( ms, length ) MS
			From
			(
				Select lineid, linenum, Cast ( sum ( CAST ( TimeStop - TimeAnswer as float ) ) as DateTime ) length From
				(
					Select ALineId as lineid, ALineNum as linenum, 
						TimeAnswer, TimeStop
					From #tempstatistics ts
					Inner Join @lines l on l.lineid = ts.ALineId
	
					Union all
	
					Select BLineId as lineid, BLineNum as linenum, 
						TimeAnswer, TimeStop
					From #tempstatistics ts
					Inner Join @lines l on l.lineid = ts.BLineId
				)a
				Group by lineid, linenum
			)b
				Left join @lines l on b.lineid = l.lineid
		end

	--EStatisticsViewMode.svmByNumber:						
	else if ( @mode = 4 )
		begin
			declare @t table ( nid uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, reactid uniqueidentifier )
			declare @temp table ( id uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, oldrid uniqueidentifier, newrid uniqueidentifier )
				
			Insert Into @t
				Select np.Id, np.Prefix, rr.InnerAddressType, rr.ReactId
				From A_NumberPlan np
					Inner Join A_NumberPlanAction na on na.NumId = np.Id
					Inner Join A_Rules r on na.ExtraId = r.Id
					Inner Join A_RuleRecords rr on rr.RuleId = r.Id


			declare @cnt int
			set @cnt = 0

			while ( @@rowcount > 0 ) and ( @cnt < 10 )
			begin
				Set @cnt = @cnt + 1
	
				/*    @cnt - */
				Insert Into @temp
					Select t.nid, t.prefix, t.addrtype, t.reactid, t1.reactid
					From @t t
						Inner Join @t t1 on t.Reactid = t1.nId
					Where t.ReactId != t.Nid
	
				/*    */
				Delete From @t
					From @temp
				Where nid = id and reactid = oldrid

				/* */
				Insert Into @t ( nid, prefix, addrtype, reactid )
					Select id, prefix, addrtype, newrid From @temp

				/* */
				Delete From @temp	
			end


			declare @lines4 table ( lineid uniqueidentifier )
			insert into @lines4
				Select Id From A_View_ServerLinesAll
	

			Select prefix, ( DatePart ( dy, length ) - 1 ) * 24 + DatePart ( hh, length ) H, DatePart ( mi, length ) MI, DatePart ( ss, length ) S, DatePart ( ms, length ) MS
			From
			(
				Select prefix, Cast ( sum ( CAST ( TimeStop - TimeAnswer as float ) ) as DateTime ) length
				From
				(
					Select t1.prefix, 0 as InnerAddrType, TimeAnswer, TimeStop
					From #tempstatistics t Inner Join 
						@t t1 on t1.reactid = t.AUserId and t1.addrtype = 0 Inner Join 
						A_Users u on u.id = AUserId

					Union all

					Select t1.prefix, 0 as InnerAddrType, TimeAnswer, TimeStop
					From #tempstatistics t Inner Join 
						@t t1 on t1.reactid = t.BUserId and t1.addrtype = 0 Inner Join 
						A_Users u on u.id = BUserId
	
					Union all

					Select t1.prefix, 1 as InnerAddrType, TimeAnswer, TimeStop
					From #tempstatistics t Inner Join 
						@t t1 on t1.reactid = t.ALineId and t1.addrtype = 1 inner join
						@lines4 l on l.lineid = ALineId

					Union all

					Select t1.prefix, 1 as InnerAddrType, TimeAnswer, TimeStop
					From #tempstatistics t Inner Join 
						@t t1 on t1.reactid = t.BLineId and t1.addrtype = 1 inner join
						@lines4 l on l.lineid = BLineId
				)b
				Group by prefix
			)c

		end
	--EStatisticsViewMode.svmByWeekDay:
	else if ( @mode = 5 )
		begin
			--drop table #tempstatisticsYMDWDdateInt
 			if not exists ( Select * From tempdb..sysobjects where id = object_id('tempdb..#tempstatisticsYMDWDdateInt') )
				Select top 0 1 as WDay, CAST(1 as FLOAT) as Seconds, 1 as count_
				into #tempstatisticsYMDWDdateInt
				From A_Stat_Connections_1x1
			else
				delete From #tempstatisticsYMDWDdateInt


			insert into #tempstatisticsYMDWDdateInt
				select (datepart(dw, TimeStart)+5)%7 as WDay, ISNULL(SUM(CAST(TimeStop-TimeAnswer as FLOAT))*86400,0) as Seconds, count(*) as count_ From #tempstatistics
				Group By (datepart(dw, TimeStart)+5)%7
				Order By (datepart(dw, TimeStart)+5)%7


			Select WDay, Seconds  as AverageSec
			From #tempstatisticsYMDWDdateInt


			delete From #tempstatisticsYMDWDdateInt
		end

	delete From #tempstatistics

end
GO


if exists ( Select * from sysobjects where id=object_id ( 'dbo.A_Stat_Office_Diagramm_FlashedCalls' ) )
	Drop procedure dbo.A_Stat_Office_Diagramm_FlashedCalls
GO

Create procedure [dbo].[A_Stat_Office_Diagramm_FlashedCalls]
	@iduser uniqueidentifier,
	@dstart datetime,
	@dstop datetime,
	@tstart datetime,
	@tstop datetime,
	@lentime datetime,
	@taskid uniqueidentifier = null,
	@fromcc bit = null,
	@operatorid uniqueidentifier = null,
	@innerprefix nvarchar ( 100 ) = null,
	@outnumber nvarchar ( 100 ) = null,
	@conntype int = -1,
	@mode int,
	@comment nvarchar ( 4000 ) = NULL
as

begin
-- .  "  "

/*
-- ---------------------------------------------------
	declare @iduser uniqueidentifier
	declare @dstart datetime
	declare @dstop datetime
	declare @tstart datetime
	declare @tstop datetime
	declare @lentime datetime
	declare @taskid uniqueidentifier
	declare @operatorid uniqueidentifier
	declare @innerprefix nvarchar ( 100 )
	declare @outnumber nvarchar ( 100 )
	declare @mode int

	Select @iduser = 'DA803F01-EA77-40FA-BC9D-E2EFB36FD5A8', 
		@dstart = '15.06.2006', 
		@dstop = '20.12.2006', 
		@tstart = '8:00', 
		@tstop = '20:00', 
		@lentime = '0:00:01',
		@mode = 0
--------------------------------------------------------------------
*/	

	if not exists ( Select * From tempdb..sysobjects where id = object_id('tempdb..#tempstatistics') )
		Select top 0 * into #tempstatistics From A_Stat_Connections_1x1
	else
		delete From #tempstatistics
		
	Insert into #tempstatistics 
	Exec A_Stat_Service_FillTempByFilter
		@iduser,
		@dstart,
		@dstop,
		@tstart,
		@tstop,
		@lentime,
		@taskid,
		@fromcc,
		@operatorid,
		@innerprefix,
		@outnumber,
		@conntype,
		0, -- dont show conf
		@comment

	if not exists ( Select * From tempdb..sysobjects where id = object_id('tempdb..#tempstatisticsflash') )
		Select top 0 sc1.*, sc2.ALineId A2LineId, sc2.BLineId B2LineId into #tempstatisticsflash From A_Stat_Connections_1x1 sc1 Inner Join A_Stat_Connections_1x1 sc2 on sc1.IDNext = sc2.Id
	else
		delete From #tempstatisticsflash

	insert into #tempstatisticsflash
		Select ts1.*, ts2.ALineId A2LineId, ts2.BLineId B2LineId
		From #tempstatistics ts1 Inner Join 
			#tempstatistics ts2 on ts1.idnext = ts2.id
		where not ( ts1.ALineId = ts2.ALineId and ts1.BLineID = ts2.BLineId ) 
			and not ( ts1.ALineId = ts2.BLineId and ts1.BLineID = ts2.ALineId )
			and not ( ts1.AUserId = 'AB000000-0000-0000-0000-000000000000' )
			and not ( ts1.BUserId = 'AB000000-0000-0000-0000-000000000000' )


	--EStatisticsViewMode.svmByDay:
	if ( @mode = 0 )
 		begin						
			Select Year ( timestop ) y, Month ( timestop ) m, Day ( timestop ) d, count ( * ) as Count_
			From #tempstatisticsflash
			Group by Year ( timestop ), Month ( timestop ), Day ( timestop )											
		end

	--EStatisticsViewMode.svmByHour:
	else if ( @mode = 1 )
		begin
			Select DatePart ( hour, timestop ) h, count ( * ) as Count_
			From #tempstatisticsflash
			Group by DatePart ( hour, timestop )
		end

	--EStatisticsViewMode.svmByOperator:
	else if ( @mode = 2 )
		begin							
			Select uid, count ( * ) as count_
			From
			( 
				Select AUserId as uid, TimeStop
				From #tempstatisticsflash
				where StopSide = 0 and 
					(AUserId != '00000000-0000-0000-0000-000000000000')
		
				Union all

				Select BUserId as uid, TimeStop
				From #tempstatisticsflash
				where StopSide = 1 and
					(BUserId != '00000000-0000-0000-0000-000000000000')
			)a
			Group by uid								
		end

	--EStatisticsViewMode.svmByLine:
	else if ( @mode = 3 )
		begin			
			declare @lines table ( lineid uniqueidentifier, caption nvarchar ( 100 ) )
			insert into @lines (lineid, caption)
				Select id, caption From A_View_ServerLinesAll											
			
			Select linenum + case when (( not l.caption is NULL ) and ( l.caption != '' )) then ', ' + l.caption else '' end as linenum,
				count_
			From
			(
				Select lineid, linenum, count ( * ) as count_
				from
				(
					Select BLineNum as lineid, BLineNum linenum, TimeStop
					From #tempstatisticsflash ts 
					Inner Join @lines l on ts.BLineId = l.lineid

					union
	
					Select ALineNum as lineid, ALineNum linenum, TimeStop
					From #tempstatisticsflash ts 
					Inner Join @lines l on ts.ALineId = l.lineid
				)a
				group by lineid, linenum
			)
			b
				Left join @lines l on b.lineid = l.lineid
		end

	--EStatisticsViewMode.svmByNumber:						
	else if ( @mode = 4 )
		begin
			declare @t table ( nid uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, reactid uniqueidentifier )
			declare @temp table ( id uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, oldrid uniqueidentifier, newrid uniqueidentifier )
				
			Insert Into @t
				Select np.Id, np.Prefix, rr.InnerAddressType, rr.ReactId
				From A_NumberPlan np
					Inner Join A_NumberPlanAction na on na.NumId = np.Id
					Inner Join A_Rules r on na.ExtraId = r.Id
					Inner Join A_RuleRecords rr on rr.RuleId = r.Id


			declare @cnt int
			set @cnt = 0

			while ( @@rowcount > 0 ) and ( @cnt < 10 )
			begin
				Set @cnt = @cnt + 1
	
				/*    @cnt - */
				Insert Into @temp
					Select t.nid, t.prefix, t.addrtype, t.reactid, t1.reactid
					From @t t
						Inner Join @t t1 on t.Reactid = t1.nId
					Where t.ReactId != t.Nid
	
				/*    */
				Delete From @t
					From @temp
				Where nid = id and reactid = oldrid

				/* */
				Insert Into @t ( nid, prefix, addrtype, reactid )
					Select id, prefix, addrtype, newrid From @temp

				/* */
				Delete From @temp	
			end

			declare @lines4 table ( lineid uniqueidentifier )
			insert into @lines4
				Select Id From A_View_ServerIntLinesAll


			Select prefix, sum ( count_ ) count_ from
			(
				Select t1.prefix, 0 as InnerAddrType, count ( * ) as count_
				From #tempstatisticsflash t Inner Join 
					@t t1 on t1.reactid = t.AUserId and t1.addrtype = 0 Inner Join 
					A_Users u on u.id = AUserId
				Group by prefix
					
				Union all

					Select t1.prefix, 0 as InnerAddrType, count ( * ) as count_
				From #tempstatisticsflash t Inner Join 
					@t t1 on t1.reactid = t.BUserId and t1.addrtype = 0 Inner Join 
					A_Users u on u.id = BUserId
				Group by prefix
					
				Union all

					Select t1.prefix, 1 as InnerAddrType, count ( * ) as count_
				From #tempstatisticsflash t Inner Join 
					@t t1 on t1.reactid = t.ALineId and t1.addrtype = 1 inner join
					@lines l on l.lineid = ALineId
				Group by prefix
					
				Union all

				Select t1.prefix, 1 as InnerAddrType, count ( * ) as count_
				From #tempstatisticsflash t Inner Join 
					@t t1 on t1.reactid = t.BLineId and t1.addrtype = 1 inner join
					@lines l on l.lineid = BLineId
				Group by prefix
			)a
			Group by prefix

		end
	--EStatisticsViewMode.svmByWeekDay:
	else if ( @mode = 5 )
		begin
			select (DatePart(dw, TimeStart)+5)%7 as WDay, count(*) as count_
			From #tempstatisticsflash
			Group by (DatePart(dw, TimeStart)+5)%7
			Order by WDay
		end

	delete From #tempstatisticsflash
	delete From #tempstatistics

end
GO


if exists ( Select * from sysobjects where id=object_id ( 'dbo.A_Stat_Office_Diagramm_HandledCalls' ) )
	Drop procedure dbo.A_Stat_Office_Diagramm_HandledCalls
GO

Create procedure [dbo].[A_Stat_Office_Diagramm_HandledCalls]
	@iduser uniqueidentifier,
	@dstart datetime,
	@dstop datetime,
	@tstart datetime,
	@tstop datetime,
	@lentime datetime,
	@taskid uniqueidentifier = null,
	@fromcc bit = null,
	@operatorid uniqueidentifier = null,
	@innerprefix nvarchar ( 100 ) = null,
	@outnumber nvarchar ( 100 ) = null,
	@conntype int = -1,
	@mode int,
	@comment nvarchar ( 4000 ) = NULL
as

begin
-- .  "  "

/*
-- ---------------------------------------------------
	declare @iduser uniqueidentifier
	declare @dstart datetime
	declare @dstop datetime
	declare @tstart datetime
	declare @tstop datetime
	declare @lentime datetime
	declare @taskid uniqueidentifier
	declare @operatorid uniqueidentifier
	declare @innerprefix nvarchar ( 100 )
	declare @outnumber nvarchar ( 100 )
	declare @mode int

	Select @iduser = 'DA803F01-EA77-40FA-BC9D-E2EFB36FD5A8', 
		@dstart = '15.06.2006', 
		@dstop = '20.12.2006', 
		@tstart = '8:00', 
		@tstop = '20:00', 
		@lentime = '0:00:01',
		@mode = 2
--------------------------------------------------------------------
*/		

	if not exists ( Select * From tempdb..sysobjects where id = object_id('tempdb..#tempstatistics') )
		Select top 0 * into #tempstatistics From A_Stat_Connections_1x1
	else
		delete From #tempstatistics
		
	Insert into #tempstatistics 
	Exec A_Stat_Service_FillTempByFilter
		@iduser,
		@dstart,
		@dstop,
		@tstart,
		@tstop,
		@lentime,
		@taskid,
		@fromcc,
		@operatorid,
		@innerprefix,
		@outnumber,
		@conntype,
		0, -- dont show conf
		@comment

	Delete From #tempstatistics
	Where not ConnectionType in ( 4, 5 )

	Delete From #tempstatistics
	Where ConnectionType = 4 and ( not IdNext is null )


	--EStatisticsViewMode.svmByDay:
	if ( @mode = 0 )
 		begin						
			declare @k0 table ( idchain uniqueidentifier, timestop datetime )
			Insert into @k0
				Select IDChain, Max(TimeStop) as TimeStop
				From #tempstatistics							
				Group by IDChain


			Select Year ( timestop ) y, Month ( timestop ) m, Day ( timestop ) d, count ( * ) as Count_
			From @k0
			Group by Year ( timestop ), Month ( timestop ), Day ( timestop )						
		end

	--EStatisticsViewMode.svmByHour:
	else if ( @mode = 1 )
		begin
			declare @k1 table ( idchain uniqueidentifier, timestop datetime )
			Insert into @k1
				Select IDChain, Max(TimeStop) as TimeStop
				From #tempstatistics
				Group by IDChain

			Select DatePart ( hour, timestop ) h, count ( * ) as Count_
			From @k1
			Group by DatePart ( hour, timestop )
		end

	--EStatisticsViewMode.svmByOperator:
	else if ( @mode = 2 )
		begin							
				Select BUserId, count ( * ) as count_
				From #tempstatistics
				group by BUserId													
		end

	--EStatisticsViewMode.svmByLine:
	else if ( @mode = 3 )
		begin														
			Select BLineNum, count ( * ) as count_
			From #tempstatistics
			group by BLineNum
		end

	--EStatisticsViewMode.svmByNumber:						
	else if ( @mode = 4 )
	begin
		declare @t table ( nid uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, reactid uniqueidentifier )
		declare @temp table ( id uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, oldrid uniqueidentifier, newrid uniqueidentifier )
				
		Insert Into @t
			Select np.Id, np.Prefix, rr.InnerAddressType, rr.ReactId
			From A_NumberPlan np
				Inner Join A_NumberPlanAction na on na.NumId = np.Id
				Inner Join A_Rules r on na.ExtraId = r.Id
				Inner Join A_RuleRecords rr on rr.RuleId = r.Id


		declare @cnt int
		set @cnt = 0

		while ( @@rowcount > 0 ) and ( @cnt < 10 )
		begin
			Set @cnt = @cnt + 1
	
			/*    @cnt - */
			Insert Into @temp
				Select t.nid, t.prefix, t.addrtype, t.reactid, t1.reactid
				From @t t
					Inner Join @t t1 on t.Reactid = t1.nId
				Where t.ReactId != t.Nid
	
			/*    */
			Delete From @t
				From @temp
			Where nid = id and reactid = oldrid

			/* */
			Insert Into @t ( nid, prefix, addrtype, reactid )
				Select id, prefix, addrtype, newrid From @temp

			/* */
			Delete From @temp	
		end

			declare @lines table ( lineid uniqueidentifier )
			insert into @lines
				Select Id From A_View_ServerIntLinesAll


			Select prefix, sum ( count_ ) count_ from
			(
				Select t1.prefix, 0 as InnerAddrType, count ( * ) as count_
				From #tempstatistics t Inner Join 
					@t t1 on t1.reactid = t.BUserId and t1.addrtype = 0 Inner Join 
					A_Users u on u.id = BUserId
				Group by prefix

				Union all

				Select t1.prefix, 1 as InnerAddrType, count ( * ) as count_
				From #tempstatistics t Inner Join 
					@t t1 on t1.reactid = t.BLineId and t1.addrtype = 1 inner join
					@lines l on l.lineid = BLineId
				Group by prefix
			)a
			Group by prefix
	end	

	delete From #tempstatistics

end
GO


if exists ( Select * from sysobjects where id=object_id ( 'dbo.A_Stat_Office_TimeScale' ) )
	Drop procedure dbo.A_Stat_Office_TimeScale
GO

Create procedure [dbo].[A_Stat_Office_TimeScale]
	@iduser		uniqueidentifier,
	@dstart 	DateTime, 
	@dstop	 	DateTime, 
	@tstart 	DateTime, 
	@tstop	 	DateTime,
	@lentime 	DateTime,
	@conntype 	int 			= -1, 
	@taskid		uniqueidentifier 	= null,
	@fromcc		bit			= null,
	@operatorid 	uniqueidentifier 	= null,
	@innerprefix 	nvarchar ( 20 )		= null, 
	@outnumber 	nvarchar ( 20 )		= null,
	@comment 	nvarchar ( 4000 ) 	= NULL,

	@minvalue 	int 			output, 
	@maxvalue 	int 			output
as
begin
--    
/*
----------------------------------------------------------
------- debug --------------------------------------------
----------------------------------------------------------
	declare @dstart 	DateTime 
	declare @dstop	 	DateTime 
	declare @tstart 	DateTime 
	declare @tstop	 	DateTime
	declare @lentime 	DateTime
	declare @conntype 	int 
	declare @taskid		uniqueidentifier
	declare @fromcc		bit
	declare @operatorid 	uniqueidentifier
	declare @innerprefix	nvarchar ( 20 )
	declare @outnumber	nvarchar ( 20 )
	declare @iduser		uniqueidentifier
	declare @minvalue 	int
	declare @maxvalue 	int
	
	set dateformat dmy
	set @dstart = '25.12.2006' 
	set @dstop = '28.12.2006' 
	set @tstart = '8:00'
	set @tstop = '18:00' 
	set @lentime = '0:00:01' 
	set @conntype = -1
	set @taskid = N'00000000-0000-0000-0000-000000000000'
	set @operatorid = N'00000000-0000-0000-0000-000000000000'
	set @innerprefix = N'' 
	set @outnumber = N''
	set @iduser = 'DA803F01-EA77-40FA-BC9D-E2EFB36FD5A8'
	set @fromcc = 1
----------------------------------------------------------
------- end debug ----------------------------------------
----------------------------------------------------------
*/

	declare @tstartfloat float  declare @tstopfloat float 
	set @tstartfloat = Convert ( float, @tstart )  
	set @tstopfloat  = Convert ( float, @tstop )  
	set @tstartfloat = @tstartfloat - FLOOR ( @tstartfloat )  
	set @tstopfloat = @tstopfloat - FLOOR ( @tstopfloat )  


	if ( @taskid = '00000000-0000-0000-0000-000000000000' )
		set @taskid = null

	if ( @operatorid = '00000000-0000-0000-0000-000000000000' )
		set @operatorid = null

	if ( @innerprefix = '' )
		set @innerprefix = null

	if ( @outnumber = '' )
		set @outnumber = null;

	Select top 0 * into #t from A_Stat_Connections_1x1
	Insert into #t Exec A_Stat_Service_FillTempByFilter
		@iduser,
		@dstart,
		@dstop,
		'0:00',
		'23:59:59',
		@lentime,
		@taskid,
		@fromcc,
		@operatorid,
		@innerprefix,
		@outnumber,
		@conntype,
		0, -- dont show conf
		@comment


	Declare @min_ int, @max_ int;
	Declare @emptyguid uniqueidentifier
	Set @emptyguid = '00000000-0000-0000-0000-0000000000000000'



	Select @minvalue = isnull ( min ( c ), 0 ), @maxvalue = isnull ( max ( c ), 0 ) from
	(
		Select count ( * ) c 
		From #t
		--Where (( @conntype = -1 ) or ( @conntype = 1 and connectiontype in (4,5) ) or (@conntype = 2 and connectiontype in (1,6,7)) or (@conntype = 3 and connectiontype in (2,3,8)))
		Group By convert ( varchar(10), timestart, 104 ), datepart ( hour, timestart )
	) a;


	declare @empty table ( cdate varchar ( 10 ) collate database_default, c0 int, c1 int, c2 int, c3 int, c4 int, c5 int, c6 int, c7 int, c8 int, c9 int, c10 int, 
		c11 int, c12 int, c13 int, c14 int, c15 int, c16 int, c17 int, c18 int, c19 int, c20 int, c21 int, c22 int, c23 int, cbottom int, ctop int )
	declare @tempdate datetime 
	set @tempdate = @dstart
	while @tempdate < @dstop
	begin
		Insert into @empty ( cdate, c0, c1, c2, c3, c4, c5, c6, c7, c8, c9, c10, c11, c12, c13, c14, c15, c16, c17, c18, c19, c20, c21, c22, c23, cbottom, ctop )
		Values ( convert ( varchar(10), @tempdate, 126 ), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 )
			
		set @tempdate = DateAdd ( d, 1, @tempdate )
	end
	

	declare @ttt table ( cdate varchar ( 10 ) collate database_default, c0 int, c1 int, c2 int, c3 int, c4 int, c5 int, c6 int, c7 int, c8 int, c9 int, c10 int, 
		c11 int, c12 int, c13 int, c14 int, c15 int, c16 int, c17 int, c18 int, c19 int, c20 int, c21 int, c22 int, c23 int, cbottom int, ctop int )

	insert into @ttt

	Select 	cdate,
     		sum ( c0 ) as c0, 
    	 	sum ( c1 ) as c1,
     		sum ( c2 ) as c2,
	     	sum ( c3 ) as c3,
     		sum ( c4 ) as c4,
     		sum ( c5 ) as c5, 
     		sum ( c6 ) as c6,
     		sum ( c7 ) as c7,
     		sum ( c8 ) as c8,
     		sum ( c9 ) as c9,
     		sum ( c10 ) as c10, 
     		sum ( c11 ) as c11, 
     		sum ( c12 ) as c12,
     		sum ( c13 ) as c13,
     		sum ( c14 ) as c14,
     		sum ( c15 ) as c15,
     		sum ( c16 ) as c16,
     		sum ( c17 ) as c17,
     		sum ( c18 ) as c18,
	     	sum ( c19 ) as c19,
	     	sum ( c20 ) as c20,
	     	sum ( c21 ) as c21,
	     	sum ( c22 ) as c22,  
	     	sum ( c23 ) as c23,
	     	sum ( cbefore ) as cbottom,
	     	sum ( cafter ) as ctop  

	From 

	(

     		Select  
			convert ( varchar(10), timestart, 126 ) cdate,
          		case ( DatePart ( hour, timestart ) ) when 0 then 1 else 0 end as c0,
         		case ( DatePart ( hour, timestart ) ) when 1 then 1 else 0 end as c1,
          		case ( DatePart ( hour, timestart ) ) when 2 then 1 else 0 end as c2,
          		case ( DatePart ( hour, timestart ) ) when 3 then 1 else 0 end as c3,
          		case ( DatePart ( hour, timestart ) ) when 4 then 1 else 0 end as c4,
          		case ( DatePart ( hour, timestart ) ) when 5 then 1 else 0 end as c5,
          		case ( DatePart ( hour, timestart ) ) when 6 then 1 else 0 end as c6,
          		case ( DatePart ( hour, timestart ) ) when 7 then 1 else 0 end as c7,
          		case ( DatePart ( hour, timestart ) ) when 8 then 1 else 0 end as c8,
          		case ( DatePart ( hour, timestart ) ) when 9 then 1 else 0 end as c9,
          		case ( DatePart ( hour, timestart ) ) when 10 then 1 else 0 end as c10,
          		case ( DatePart ( hour, timestart ) ) when 11 then 1 else 0 end as c11,
          		case ( DatePart ( hour, timestart ) ) when 12 then 1 else 0 end as c12,
          		case ( DatePart ( hour, timestart ) ) when 13 then 1 else 0 end as c13,
	          	case ( DatePart ( hour, timestart ) ) when 14 then 1 else 0 end as c14,
	          	case ( DatePart ( hour, timestart ) ) when 15 then 1 else 0 end as c15,
	          	case ( DatePart ( hour, timestart ) ) when 16 then 1 else 0 end as c16,
	          	case ( DatePart ( hour, timestart ) ) when 17 then 1 else 0 end as c17,
	          	case ( DatePart ( hour, timestart ) ) when 18 then 1 else 0 end as c18,
	          	case ( DatePart ( hour, timestart ) ) when 19 then 1 else 0 end as c19,
	          	case ( DatePart ( hour, timestart ) ) when 20 then 1 else 0 end as c20,
	          	case ( DatePart ( hour, timestart ) ) when 21 then 1 else 0 end as c21,
	          	case ( DatePart ( hour, timestart ) ) when 22 then 1 else 0 end as c22,
	          	case ( DatePart ( hour, timestart ) ) when 23 then 1 else 0 end as c23,			
			case when Convert ( float, TimeStart ) - FLOOR ( Convert ( float, TimeStart ) ) < @tstartfloat then 1 else 0 end as cbefore,
			case when Convert ( float, TimeStart ) - FLOOR ( Convert ( float, TimeStart ) ) > @tstopfloat then 1 else 0 end as cafter


     		From 
		(
			/*
			Select IdChain, TimeStart		
			From #t
			--Where ((@conntype = -1) or (@conntype = 1 and connectiontype in (4,5)) or (@conntype = 2 and connectiontype in (1,6,7)) or ( @conntype = 3 and connectiontype in (2,3,8)))
	          	Group By IdChain, TimeStart
			*/
			select 
			(select top 1 TimeStart from #t where 
			IdChain=tt.IdChain order by TimeStart) as timestart
			from #t tt
			group by IdChain
		)b

		Union all

		Select *
		FROM @empty
	)a

	Group by cdate
	Order by cdate

	
	declare @mxv1 int
	declare @mxv2 int
	Select @mxv1 = Max ( ctop ) From @ttt
	Select @mxv2 = Max ( cbottom ) From @ttt
	if ( @maxvalue < @mxv1 )
		Set @maxvalue = @mxv1
	if ( @maxvalue < @mxv2 )
		Set @maxvalue = @mxv2

	Select * 
	From @ttt
end
GO


if exists ( Select * from sysobjects where id=object_id ( 'dbo.A_Stat_Office_TimeScale2' ) )
	Drop procedure dbo.A_Stat_Office_TimeScale2
GO

Create procedure [dbo].[A_Stat_Office_TimeScale2]
	@iduser		uniqueidentifier,
	@dstart 	DateTime, 
	@dstop	 	DateTime, 
	@tstart 	DateTime, 
	@tstop	 	DateTime,
	@lentime 	DateTime,
	@conntype 	int 			= -1, 
	@taskid		uniqueidentifier 	= null,
	@fromcc		bit			= null,
	@operatorid 	uniqueidentifier 	= null,
	@innerprefix 	nvarchar ( 20 )		= null, 
	@outnumber 	nvarchar ( 20 )		= null,
	@comment 	nvarchar ( 4000 )	= null,

	@minvalue 	int 			output, 
	@maxvalue 	int 			output
as
begin
--    ,   
/*
----------------------------------------------------------
------- debug --------------------------------------------
----------------------------------------------------------
	declare @dstart 	DateTime 
	declare @dstop	 	DateTime 
	declare @tstart 	DateTime 
	declare @tstop	 	DateTime
	declare @lentime 	DateTime
	declare @conntype 	int 
	declare @taskid		uniqueidentifier
	declare @fromcc		bit
	declare @operatorid 	uniqueidentifier
	declare @innerprefix	nvarchar ( 20 )
	declare @outnumber	nvarchar ( 20 )
	declare @iduser		uniqueidentifier
	declare @minvalue 	int
	declare @maxvalue 	int
	
	set dateformat dmy
	set @dstart = '25.12.2006' 
	set @dstop = '28.12.2006' 
	set @tstart = '8:00'
	set @tstop = '18:00' 
	set @lentime = '0:00:01' 
	set @conntype = -1
	set @taskid = N'00000000-0000-0000-0000-000000000000'
	set @operatorid = N'00000000-0000-0000-0000-000000000000'
	set @innerprefix = N'' 
	set @outnumber = N''
	set @iduser = 'DA803F01-EA77-40FA-BC9D-E2EFB36FD5A8'
	set @fromcc = 1
----------------------------------------------------------
------- end debug ----------------------------------------
----------------------------------------------------------
*/

	declare @tstartfloat float  declare @tstopfloat float 
	set @tstartfloat = Convert ( float, @tstart )  
	set @tstopfloat  = Convert ( float, @tstop )  
	set @tstartfloat = @tstartfloat - FLOOR ( @tstartfloat )  
	set @tstopfloat = @tstopfloat - FLOOR ( @tstopfloat )  


	if ( @taskid = '00000000-0000-0000-0000-000000000000' )
		set @taskid = null

	if ( @operatorid = '00000000-0000-0000-0000-000000000000' )
		set @operatorid = null

	if ( @innerprefix = '' )
		set @innerprefix = null

	if ( @outnumber = '' )
		set @outnumber = null;

	Select top 0 * into #t from A_Stat_Connections_1x1
	Insert into #t Exec A_Stat_Service_FillTempByFilter
		@iduser,
		@dstart,
		@dstop,
		'0:00',
		'23:59:59',
		@lentime,
		@taskid,
		@fromcc,
		@operatorid,
		@innerprefix,
		@outnumber,
		@conntype,
		0, -- dont show conf
		@comment	



	Declare @min_ int, @max_ int;
	Declare @emptyguid uniqueidentifier
	Set @emptyguid = '00000000-0000-0000-0000-0000000000000000'



	Select @minvalue = isnull ( min ( c ), 0 ), @maxvalue = isnull ( max ( c ), 0 ) from
	(
		Select count ( * ) c 
		From ( 
			Select IdChain, Min(TimeStart) as TimeStart, Max(TimeStop) as TimeStop 
			From #t 
			Group By IdChain
			)b
		--Where (( @conntype = -1 ) or ( @conntype = 1 and connectiontype in (4,5) ) or (@conntype = 2 and connectiontype in (1,6,7)) or (@conntype = 3 and connectiontype in (2,3,8)))
		Group By convert ( varchar(10), timestart, 104 ), datepart ( hour, timestart )
	) a;


	declare @empty table ( cdate varchar ( 10 ) collate database_default, c0 int, c1 int, c2 int, c3 int, c4 int, c5 int, c6 int, c7 int, c8 int, c9 int, c10 int, 
		c11 int, c12 int, c13 int, c14 int, c15 int, c16 int, c17 int, c18 int, c19 int, c20 int, c21 int, c22 int, c23 int, cbottom int, ctop int )
	declare @tempdate datetime 
	set @tempdate = @dstart
	while @tempdate < @dstop
	begin
		Insert into @empty ( cdate, c0, c1, c2, c3, c4, c5, c6, c7, c8, c9, c10, c11, c12, c13, c14, c15, c16, c17, c18, c19, c20, c21, c22, c23, cbottom, ctop )
		Values ( convert ( varchar(10), @tempdate, 126 ), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 )
			
		set @tempdate = DateAdd ( d, 1, @tempdate )
	end
	

	declare @ttt table ( cdate varchar ( 10 ) collate database_default, c0 int, c1 int, c2 int, c3 int, c4 int, c5 int, c6 int, c7 int, c8 int, c9 int, c10 int, 
		c11 int, c12 int, c13 int, c14 int, c15 int, c16 int, c17 int, c18 int, c19 int, c20 int, c21 int, c22 int, c23 int, cbottom int, ctop int )

	insert into @ttt

	Select 	cdate,
     		sum ( c0 ) as c0, 
    	 	sum ( c1 ) as c1,
     		sum ( c2 ) as c2,
	     	sum ( c3 ) as c3,
     		sum ( c4 ) as c4,
     		sum ( c5 ) as c5, 
     		sum ( c6 ) as c6,
     		sum ( c7 ) as c7,
     		sum ( c8 ) as c8,
     		sum ( c9 ) as c9,
     		sum ( c10 ) as c10, 
     		sum ( c11 ) as c11, 
     		sum ( c12 ) as c12,
     		sum ( c13 ) as c13,
     		sum ( c14 ) as c14,
     		sum ( c15 ) as c15,
     		sum ( c16 ) as c16,
     		sum ( c17 ) as c17,
     		sum ( c18 ) as c18,
	     	sum ( c19 ) as c19,
	     	sum ( c20 ) as c20,
	     	sum ( c21 ) as c21,
	     	sum ( c22 ) as c22,  
	     	sum ( c23 ) as c23,
	     	sum ( cbefore ) as cbottom,
	     	sum ( cafter ) as ctop  

	From 

	(

     		Select  
			convert ( varchar(10), timestart, 126 ) cdate,
          		case ( DatePart ( hour, timestart ) ) when 0 then 1 else 0 end as c0,
         		case ( DatePart ( hour, timestart ) ) when 1 then 1 else 0 end as c1,
          		case ( DatePart ( hour, timestart ) ) when 2 then 1 else 0 end as c2,
          		case ( DatePart ( hour, timestart ) ) when 3 then 1 else 0 end as c3,
          		case ( DatePart ( hour, timestart ) ) when 4 then 1 else 0 end as c4,
          		case ( DatePart ( hour, timestart ) ) when 5 then 1 else 0 end as c5,
          		case ( DatePart ( hour, timestart ) ) when 6 then 1 else 0 end as c6,
          		case ( DatePart ( hour, timestart ) ) when 7 then 1 else 0 end as c7,
          		case ( DatePart ( hour, timestart ) ) when 8 then 1 else 0 end as c8,
          		case ( DatePart ( hour, timestart ) ) when 9 then 1 else 0 end as c9,
          		case ( DatePart ( hour, timestart ) ) when 10 then 1 else 0 end as c10,
          		case ( DatePart ( hour, timestart ) ) when 11 then 1 else 0 end as c11,
          		case ( DatePart ( hour, timestart ) ) when 12 then 1 else 0 end as c12,
          		case ( DatePart ( hour, timestart ) ) when 13 then 1 else 0 end as c13,
	          	case ( DatePart ( hour, timestart ) ) when 14 then 1 else 0 end as c14,
	          	case ( DatePart ( hour, timestart ) ) when 15 then 1 else 0 end as c15,
	          	case ( DatePart ( hour, timestart ) ) when 16 then 1 else 0 end as c16,
	          	case ( DatePart ( hour, timestart ) ) when 17 then 1 else 0 end as c17,
	          	case ( DatePart ( hour, timestart ) ) when 18 then 1 else 0 end as c18,
	          	case ( DatePart ( hour, timestart ) ) when 19 then 1 else 0 end as c19,
	          	case ( DatePart ( hour, timestart ) ) when 20 then 1 else 0 end as c20,
	          	case ( DatePart ( hour, timestart ) ) when 21 then 1 else 0 end as c21,
	          	case ( DatePart ( hour, timestart ) ) when 22 then 1 else 0 end as c22,
	          	case ( DatePart ( hour, timestart ) ) when 23 then 1 else 0 end as c23,			
			case when Convert ( float, TimeStart ) - FLOOR ( Convert ( float, TimeStart ) ) < @tstartfloat then 1 else 0 end as cbefore,
			case when Convert ( float, TimeStart ) - FLOOR ( Convert ( float, TimeStart ) ) > @tstopfloat then 1 else 0 end as cafter


     		From 
		(
			Select IdChain, TimeStart		
			From ( 
				Select IdChain, Min(TimeStart) as TimeStart, Max(TimeStop) as TimeStop 
				From #t 
				Group By IdChain
				)b
			--Where ((@conntype = -1) or (@conntype = 1 and connectiontype in (4,5)) or (@conntype = 2 and connectiontype in (1,6,7)) or ( @conntype = 3 and connectiontype in (2,3,8)))
	          	Group By IdChain, TimeStart
		)b

		Union all

		Select *
		FROM @empty
	)a

	Group by cdate
	Order by cdate

	
	declare @mxv1 int
	declare @mxv2 int
	Select @mxv1 = Max ( ctop ) From @ttt
	Select @mxv2 = Max ( cbottom ) From @ttt
	if ( @maxvalue < @mxv1 )
		Set @maxvalue = @mxv1
	if ( @maxvalue < @mxv2 )
		Set @maxvalue = @mxv2

	Select * 
	From @ttt
end
GO
